---
title: <span class="badge object-type-scalar"></span> Hexadecimal
---
# <span class="badge object-type-scalar"></span> Hexadecimal

## Definition

```python
Hexadecimal: typing.Literal["hex"] = "hex"
```
